Package: ISwR
Version: 2.0-12
Date: 2026-05-20
Title: Introductory Statistics with R
Authors@R: person(given = "Peter",
                     family = "Dalgaard",
                     role = c("aut", "cre"),
                     email = "pd.mes@cbs.dk")
Description: Data sets and scripts for text examples and exercises in 
  P. Dalgaard (2008), `Introductory Statistics with R', 2nd ed., Springer Verlag, ISBN 978-0387790534.  
Depends: R (>= 2.6.0)
Suggests: survival,MASS
License: GPL (>= 2)
ZipData: no
LazyData: yes
NeedsCompilation: no
Packaged: 2026-05-20 16:38:01 UTC; pd
Author: Peter Dalgaard [aut, cre]
Maintainer: Peter Dalgaard <pd.mes@cbs.dk>
Repository: CRAN
Date/Publication: 2026-05-21 05:10:32 UTC
Built: R 4.5.2; ; 2026-05-25 01:13:35 UTC; unix
