x <- 1:5 ; y <- rexp(5,1) ; opar <- par(mfrow=c(2,2))
plot(x, y, pch=15) # filled square
plot(x, y, type="b", lty="dotted")
plot(x, y, type="b", lwd=3)
plot(x, y, type="o", col="blue")
par(opar)
plot(rnorm(10),type="o", pch=21, bg="white")
x1 <- rnorm(20)
x2 <- rnorm(10)+1
q1 <- qqnorm(x1, plot.it=F)
q2 <- qqnorm(x2, plot.it=F)
xr <- range(q1$x, q2$x)
yr <- range(q1$y, q2$y)
qqnorm(x1, xlim=xr, ylim=yr)
points(q2, col="red")
hist(react)
library(MASS)
truehist(react,h=1,x0=.5)
z <- runif(5)
curve(quantile(z,x), from=0, to=1)
rm(list=ls())
while(search()[2] != "package:ISwR") detach()
